@@ -14,7 +14,7 @@
 #define INPUT_SIZE 512
 
 #ifdef UNICODE
- wpath_t wstr;
+ static wpath_t wstr;
 #endif
 
 extern void deletefiles(file_t *files, int prompt, FILE *tty)
@@ -30,7 +30,7 @@ extern void deletefiles(file_t *files, int prompt, FILE *tty)
   unsigned int number, sum, max, x;
   size_t i;
 
-  if (!files) return;
+  LOUD(fprintf(stderr, "deletefiles: %p, %d, %p\n", files, prompt, tty));
 
   groups = get_max_dupes(files, &max, NULL);
 
@@ -43,7 +43,7 @@ extern void deletefiles(file_t *files, int prompt, FILE *tty)
   if (!dupelist || !preserve || !preservestr) oom("deletefiles() structures");
 
   for (; files; files = files->next) {
-    if (ISFLAG(files->flags, F_HAS_DUPES)) {
+    if (ISFLAG(files->flags, FF_HAS_DUPES)) {
       curgroup++;
       counter = 1;
       dupelist[counter] = files;
